import { ABCWidgetFactory, DocumentRegistry, IDocumentWidget, DocumentWidget } from '@jupyterlab/docregistry';
import { Signal } from '@lumino/signaling';
import { TextRenderConfig } from 'tde-csvviewer';
import { DataGrid, SelectionModel } from 'tde-datagrid';
import { Message } from '@lumino/messaging';
import { Widget } from '@lumino/widgets';
import { EditableDSVModel } from './model';
import { CommandRegistry } from '@lumino/commands';
import { GridSearchService } from './searchservice';
export declare class EditableCSVViewer extends Widget {
    private _background;
    /**
     * Construct a new CSV viewer.
     */
    constructor(options: EditableCSVViewer.IOptions);
    /**
     * The CSV widget's context.
     */
    get context(): DocumentRegistry.Context;
    /**
     * A promise that resolves when the csv viewer is ready to be revealed.
     */
    get revealed(): Promise<void>;
    /**
     * The delimiter for the file.
     */
    get delimiter(): string;
    set delimiter(value: string);
    /**
     * The style used by the data grid.
     */
    get style(): DataGrid.Style;
    set style(value: DataGrid.Style);
    get coords(): Array<number | null>;
    /**
     * The config used to create text renderer.
     */
    set rendererConfig(rendererConfig: TextRenderConfig);
    /**
     * The search service
     */
    get searchService(): GridSearchService;
    /**
     * The DataModel used to render the DataGrid
     */
    get dataModel(): EditableDSVModel;
    get changeModelSignal(): Signal<this, string>;
    /**
     * Dispose of the resources used by the widget.
     */
    dispose(): void;
    /**
     * Go to line
     */
    goToLine(lineNumber: number): void;
    /**
     * Handle `'activate-request'` messages.
     */
    protected onActivateRequest(msg: Message): void;
    /**
     * Guess the row delimiter if it was not supplied.
     * This will be fooled if a different line delimiter possibility appears in the first row.
     */
    private _guessRowDelimeter;
    /**
     * Counts the occurrences of a substring from a given string
     */
    private _countOccurrences;
    /**
     * Adds the a column header of alphabets to the top of the data (A..Z,AA..ZZ,AAA...)
     * @param colDelimiter The delimiter used to separated columns (commas, tabs, spaces)
     */
    protected _buildColHeader(colDelimiter: string): string;
    /**
     * Create the model for the grid.
     */
    protected _updateGrid(): void;
    /**
     * Update the renderer for the grid.
     */
    private _updateRenderer;
    /**
     * Updates the file based on the data model
     * @param emitter
     * @param data The raw data used to update the model
     */
    private _updateModel;
    /**
     * Saves the file
     */
    private _save;
    private _cancelEditing;
    /**
     * Handles all changes to the data model
     * @param emitter
     * @param type
     */
    private _changeModel;
    /**
     * Selects a certain cell using the selection model
     * @param row The row being selected
     * @param column The column being selected
     */
    selectSingleCell(row: number, column: number): void;
    protected getSelectedRange(): SelectionModel.Selection;
    protected onAfterAttach(msg: Message): void;
    private _handlePaste;
    private _onRightClick;
    private _onResize;
    private _region;
    private _row;
    private _column;
    private _context;
    private _grid;
    private _searchService;
    private _monitor;
    private _delimiter;
    private _revealed;
    private _baseRenderer;
    private _changeModelSignal;
    private _columnHeader;
    private _rowHeader;
}
export declare class EditableCSVDocumentWidget extends DocumentWidget<EditableCSVViewer> {
    constructor(options: EditableCSVDocumentWidget.IOptions);
    /**
     * Set URI fragment identifier for rows
     */
    setFragment(fragment: string): void;
}
export declare namespace EditableCSVDocumentWidget {
    interface IOptions extends DocumentWidget.IOptionsOptionalContent<EditableCSVViewer> {
        delimiter?: string;
        commandRegistry: CommandRegistry;
    }
}
export declare class EditableCSVViewerFactory extends ABCWidgetFactory<IDocumentWidget<EditableCSVViewer>> {
    constructor(options: DocumentRegistry.IWidgetFactoryOptions<IDocumentWidget>, commandRegistry: CommandRegistry);
    createNewWidget(context: DocumentRegistry.Context): IDocumentWidget<EditableCSVViewer>;
    private _commandReigstry;
}
export declare namespace EditableCSVViewer {
    /**
     * Instantiation options for CSV widgets.
     */
    interface IOptions {
        /**
         * The document context for the CSV being rendered by the widget.
         */
        context: DocumentRegistry.Context;
    }
}
